==> centreon-web-24.10.17.tar.gz: centreon-web-24.10.17/src/Core/Resources/Application/UseCase/CountResources/CountResourcesResponse.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Resources\Application\UseCase\CountResources;

/**
 * Class
 *
 * @class CountResourcesResponse
 * @package Core\Resources\Application\UseCase\CountResources
 */
final class CountResourcesResponse {
    /** @var int */
    private int $totalFilteredResources = 0;

    /** @var int */
    private int $totalResources = 0;

    /**
     * @return int
     */
    public function getTotalFilteredResources(): int
    {
        return $this->totalFilteredResources;
    }

    /**
     * @param int $totalFilteredResources
     *
     * @return CountResourcesResponse
     */
    public function setTotalFilteredResources(int $totalFilteredResources): self
    {
        $this->totalFilteredResources = $totalFilteredResources;

        return $this;
    }

    /**
     * @return int
     */
    public function getTotalResources(): int
    {
        return $this->totalResources;
    }

    /**
     * @param int $totalResources
     *
     * @return $this
     */
    public function setTotalResources(int $totalResources): self
    {
        $this->totalResources = $totalResources;

        return $this;
    }
}

==> centreon-web-25.09.2.tar.gz: centreon-web-25.09.2/src/Core/Resources/Application/UseCase/CountResources/CountResourcesResponse.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Resources\Application\UseCase\CountResources;

/**
 * Class
 *
 * @class CountResourcesResponse
 * @package Core\Resources\Application\UseCase\CountResources
 */
final class CountResourcesResponse
{
    /** @var int */
    private int $totalFilteredResources = 0;

    /** @var int */
    private int $totalResources = 0;

    /**
     * @return int
     */
    public function getTotalFilteredResources(): int
    {
        return $this->totalFilteredResources;
    }

    /**
     * @param int $totalFilteredResources
     *
     * @return CountResourcesResponse
     */
    public function setTotalFilteredResources(int $totalFilteredResources): self
    {
        $this->totalFilteredResources = $totalFilteredResources;

        return $this;
    }

    /**
     * @return int
     */
    public function getTotalResources(): int
    {
        return $this->totalResources;
    }

    /**
     * @param int $totalResources
     *
     * @return $this
     */
    public function setTotalResources(int $totalResources): self
    {
        $this->totalResources = $totalResources;

        return $this;
    }
}
